Temporarily revert https://github.com/rust-lang/libc/commit/5a3b5da3459b

error[E0308]: mismatched types
   --> cargo-crates/nix-0.24.3/src/sys/event.rs:227:19
    |
227 |             data: data as type_of_data,
    |                   ^^^^^^^^^^^^^^^^^^^^ expected `i64`, found `isize`

error[E0063]: missing field `ext` in initializer of `kevent`
   --> cargo-crates/nix-0.24.3/src/sys/event.rs:222:26
    |
222 |         KEvent { kevent: libc::kevent {
    |                          ^^^^^^^^^^^^ missing `ext`

--- cargo-crates/libc-0.2.177/build.rs.orig	2006-07-24 01:21:28 UTC
+++ cargo-crates/libc-0.2.177/build.rs
@@ -55,7 +55,7 @@ fn main() {
     let target_arch = env::var("CARGO_CFG_TARGET_ARCH").unwrap_or_default();
 
     // The ABI of libc used by std is backward compatible with FreeBSD 12.
     // The ABI of libc from crates.io is backward compatible with FreeBSD 12.
     //
     // On CI, we detect the actual FreeBSD version and match its ABI exactly,
     // running tests to ensure that the ABI is correct.
@@ -66,9 +66,11 @@ fn main() {
         println!("cargo:warning=setting FreeBSD version to {vers}");
         vers
     } else if libc_ci {
-        which_freebsd().unwrap_or(12)
-    } else {
+        which_freebsd().unwrap_or(11)
+    } else if rustc_dep_of_std {
         12
+    } else {
+        11
     };
 
     match which_freebsd {
@@ -55,7 +55,7 @@ fn main() {
 
     // The ABI of libc used by std is backward compatible with FreeBSD 12.
-    // The ABI of libc from crates.io is backward compatible with FreeBSD 12.
+    // The ABI of libc from crates.io is backward compatible with FreeBSD 11.
     //
     // On CI, we detect the actual FreeBSD version and match its ABI exactly,
